sqlmesh.engines.spark.db_api.errors API documentation

Edit on GitHub

# sqlmesh.engines.spark.db_api.errors

View Source

     1class SparkDbApiError(Exception):
     2    pass
     3
     4
     5class NotSupportedError(SparkDbApiError):
     6    pass
     7
     8
     9class ProgrammingError(SparkDbApiError):
    10    pass

class SparkDbApiError(builtins.Exception): View Source

    2class SparkDbApiError(Exception):
    3    pass

Common base class for all non-exit exceptions.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback

class NotSupportedError(SparkDbApiError): View Source

    6class NotSupportedError(SparkDbApiError):
    7    pass

Common base class for all non-exit exceptions.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback

class ProgrammingError(SparkDbApiError): View Source

    10class ProgrammingError(SparkDbApiError):
    11    pass

Common base class for all non-exit exceptions.

##### Inherited Members

builtins.Exception
  Exception
builtins.BaseException
  with_traceback